@@ -50,6 +50,7 @@ extern char *optarg;
 /* Reasonable defaults */
 int64_t minfree = (10 * 1024 *1024), maxfree = 0;
 size_t swapsize = (32 * 1024 * 1024);
+time_t checkdelay = 30;
 char *swapdir = "/var/tmp";
 int max_inactive_swaps = 5;
 int include_cache_mem = 1;
@@ -304,6 +305,7 @@ int swapd_swapoff(swap_t *swapfile) {
 	snprintf(cmdline, sizeof(cmdline) - 1, SWAPD_SWAPOFF_CMDLINE, swapfile->pathname);
 	swapoffret = system(cmdline);
 #  else
+/*  ... otherwise, issue a warning since we don't know what to do. */
 #    warning Dont know how to swapoff on this platform
 #  endif
 #endif
@@ -382,6 +384,8 @@ int swapd_process_config_line(const char *cmd) {
 		swapdir = strdup(argbuf[1]);
 	} else if (strcasecmp(argbuf[0], "include_cache") == 0 && argc == 2) {
 		include_cache_mem = !strcasecmp(argbuf[1], "yes");
+	} else if (strcasecmp(argbuf[0], "delay") == 0 && argc == 2) {
+		checkdelay = argbuf_int[1];
 	} else {
 		PRINTERR("Unknown command: %s/%i", argbuf[0], argc);
 	}
@@ -555,7 +559,7 @@ int main(int argc, char **argv) {
 	SPOTVAR_LL(minfree);
 
 	while (1) {
-		sleep(10);
+		sleep(checkdelay);
 
 		freemem = swapd_get_free_mem();
 		if (freemem == -1) {
